.box-controls {
    margin-bottom: 20px;
}

.box-controls a {
    margin-top: 10px;
}

body .redactor_toolbar li a.redactor_btn_browser {
    /*width: 25px;
    height: 25px;
    vertical-align: text-top;
    background-image: url("../img/glyphicons-halflings.png");
    background-repeat: no-repeat;
    background-position: -408px -120px;*/
    background: url("../img/explorer.png") no-repeat;
}

/* Upload button
------------------------------------------------------------------------------------------------------ */
.qq-upload-button {
    background: #309bbf; /* Old browsers */
    background: -moz-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#36b0d9), color-stop(100%,#309bbf)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#36b0d9', endColorstr='#309bbf',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* W3C */

    border: 1px solid #2987a6;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;

    padding: 6px;
    font: normal 13px/1 Arial, sans-serif;
    color: white;
    text-transform: uppercase;
    text-align: center;
    width: 140px;
}
.qq-upload-button:hover {
    background: #333333; /* Old browsers */
    background: -moz-linear-gradient(top, #444444 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#444444), color-stop(100%,#333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #444444 0%,#333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #444444 0%,#333333 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #444444 0%,#333333 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#444444', endColorstr='#333333',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #444444 0%,#333333 100%); /* W3C */

    border: 1px solid #333;
}
.qq-upload-list {
    position: relative;
    clear: both;
    margin-top: 8px;
    width: 100%;
    border-top: 1px solid #e0e0e0;
}
.qq-upload-list:empty {
    margin-top: 0;
    border-top: 0;
}
.qq-upload-list li {
    font: 12px Arial, sans-serif;
    padding: 8px 0;
    width: 100%;
    border-top: 1px solid #fff;
    border-bottom: 1px solid #e0e0e0;
}
.qq-upload-list li + li {
    border-top: 1px solid #fff;
}
.qq-upload-list li:last-child {
    padding-bottom: 0;
    border-bottom: 0;
}
span.qq-upload-file {
    font-weight: bold;
}
.qq-upload-failed-text {
    display: none;
}
.qq-upload-fail .qq-upload-failed-text {
    display: inline;
    margin-left: 10px;
    color: #bf3030;
    font-weight: bold;
}
.qq-upload-cancel {
    position: absolute;
    left: 334px;
    margin: 0 -2px 0 0;
    color: transparent !important;
    width: 16px;
    height: 16px;
    background: url('../img/cancel.png') top left no-repeat;
    cursor: pointer;
}
.qq-upload-cancel:hover {
    color: transparent !important;
    background: url('../img/cancel_hover.png') top left no-repeat;
}
.qq-upload-size {
    font-size: 11px;
    margin-left: 10px;
}
.progress-bar {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px; 

    background-color: #fff;
    border: 1px solid #999;
    height: 6px;
    width: 348px;
    margin: 4px 0 2px;
}
.progress-bar .content {
    background: #309bbf; /* Old browsers */
    background: -moz-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#36b0d9), color-stop(100%,#309bbf)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#444444', endColorstr='#309bbf',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* W3C */

    height: 6px;
    width: 0%;
}
.qq-upload-success .progress-bar .content {
    background: #333333; /* Old browsers */
    background: -moz-linear-gradient(top, #444444 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#444444), color-stop(100%,#333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #444444 0%,#333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #444444 0%,#333333 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #444444 0%,#333333 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#444444', endColorstr='#333333',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #444444 0%,#333333 100%); /* W3C */
}

body.rtl .qq-upload-cancel {
    left: auto;
    right: 336px;
    margin: 0;
}
body.rtl .qq-upload-list li {
    position: relative;
    float: right;
    clear: both;
    line-height: 14px;
}
body.rtl .qq-upload-list li .progress-bar{
    position: relative;
    float: right;
    clear: both;
}
body.rtl .qq-upload-list li span, 
body.rtl .qq-upload-list li a {
    float: right;
    margin-right: 0;
    margin-left: 10px;
    vertical-align: baseline;
}