


/*  Filebrowser Table
------------------------------------------------------------------------------------------------------ */

.filebrowser table td {
    font-size: 10px;
}
.filebrowser table a {
    font-size: 11px;
}
.filebrowser thead th.sorted a {
    padding-right: 13px;
}
.filebrowser thead th.filename {
    min-width: 160px;
}
.filebrowser td {
    padding: 9px 10px 6px 10px !important;
}
/*.filebrowser tr.fb_folder {
    background: #e8e8e8;
    background: -moz-linear-gradient(top, #ededed, #e8e8e8);
    background: -webkit-gradient(linear, left top, left bottom, from(#ededed), to(#e8e8e8));
}
.filebrowser tr.fb_folder td {
    border-top-color: #fff !important;
    background: transparent !important;
}*/
.filebrowser td.fb_thumbnail {
    line-height: 11px;
    padding-bottom: 0 !important;
}



/*  Filebrowser Buttons & Links
------------------------------------------------------------------------------------------------------ */

span.fb_type {
    display: inline-block;
    margin: 0 0;
    padding: 1px 0;
    color: #999;
    font-size: 11px;
    font-weight: bold;
    font-style: italic;
    border-radius: 3px; -moz-border-radius: 3px; -webkit-border-radius: 3px;
}
span.fb_type.folder {
    color: #666;
    font-weight: bold;
}

a.fb_show {
    display: inline-block;
    width: 28px;
    height: 22px;
    margin-top: 0px;
    margin-left: 8px;
    vertical-align: middle;
    white-space: nowrap;
    background: transparent url('../img/filebrowser_icon_show.gif') center center no-repeat;
}

a.fb_show:hover {
    background-image: url('../img/filebrowser_icon_show_hover.gif');
}


/*  Filebrowser Show-Preview-Link & Show-Versions-Link (uses Grappellis a.internal) ......................................... */

.filebrowser a.fb_showpreview, 
.filebrowser a.fb_showversions {
    display: block;
    margin-top: 8px;
    padding-left: 8px;
    line-height: 20px;
    white-space: nowrap;
    background-position: 0 50%;
}
.filebrowser a.fb_showpreview {
    float: left;
}
.filebrowser a.fb_showversions {
    float: left; // This is left because we arent using previews right now
}
.filebrowser a.fb_showversions {
    padding-left: 25px;
    
    background: 0 50% no-repeat scroll;
}
a.fb_showversions:link, a.fb_showversions:visited {
    background-image: url('../img/filebrowser_icon_showversions.gif');
}
a.fb_showversions:hover, a.fb_showversions:active {
    background-image: url('../img/filebrowser_icon_showversions_hover.gif');
}
.filebrowser a.fb_showpreview {
    padding-left: 16px;
    background: 0 50% no-repeat scroll;
}
a.fb_showpreview:link, a.fb_showpreview:visited {
    background-image: url('../img/icon-fb-preview.png');
}
a.fb_showpreview:hover, a.fb_showpreview:active {
    background-image: url('../img/icon-fb-preview-hover.png');
}


/*  Filebrowser View-Link (contains thumbnail) & Select-Link......................................... */

a.fb_viewlink, 
button.fb_selectlink {
    position: relative;
    top: -4px !important;
    margin-bottom: -5px !important;
}
button.fb_selectlink {
    padding-top: 3px;
    padding-bottom: 4px;
    height: 24px;
    font-size: 11px;
}
@media screen and (-webkit-min-device-pixel-ratio:0) {
    button.fb_selectlink {
        padding-top: 4px;
    }
}


/*  Filebrowser Image Preview ......................................... */

.filebrowser .fb_preview_container {
    display: none;
    position: absolute;
    z-index: 1000;
    margin-top: 25px;
    padding: 5px 5px 1px;
    border: 1px solid #bdbdbd;
    border-radius: 5px; -moz-border-radius: 5px; -webkit-border-radius: 5px;
    background: #fff;
    box-shadow: 0 10px 50px #333; -moz-box-shadow: 0 10px 50px #333; -webkit-box-shadow: 0 10px 50px #333;
}
/*.filebrowser img.fb_preview {
    max-width: 400px;
    max-height: 400px;
}*/

a.fb_view_image span {
    display: none;
    position: absolute;
    top: 1px;
    right: 0;
    padding: 5px 10px 5px 20px;
    width: auto;
    line-height: 11px;
    font-weight: bold;
    border-radius: 5px; -moz-border-radius: 5px; -webkit-border-radius: 5px;
}
a.fb_view_image:hover span {
    display: block;
    color: #83c3d9;
    background: #fff url('../img/icon-fb-view-image-hover.png') 8px 7px no-repeat scroll;
}



/*  Filebrowser Pulldown Actions
------------------------------------------------------------------------------------------------------ */

.pulldown-actions-container {
    position: relative;
}
.pulldown-actions-handler {
    display: block;
    width: 27px;
    height: 17px;
    background: transparent 50% 50% no-repeat scroll;
}
.pulldown-actions-handler:link, .pulldown-actions-handler:visited {
    background-image: url('../img/icon-pulldown-actions.png');
}
.pulldown-actions-handler:hover, .pulldown-actions-handler:active {
    background-image: url('../img/icon-pulldown-actions-hover.png');
}
.open .pulldown-actions-handler {
    background-image: url('../img/icon-pulldown-actions-active.png');
}
ul.pulldown-actions {
    display: none;
}
.open ul.pulldown-actions {
    display: block;
    position: absolute;
    right: 0;
    z-index: 1000;
    margin: 3px 0 0;
    padding: 0;
    border: 1px solid #ccc;
    border-radius: 5px; -moz-border-radius: 5px; -webkit-border-radius: 5px;
    background: #eee;
    box-shadow: 0 0 50px #333; -moz-box-shadow: 0 0 50px #333; -webkit-box-shadow: 0 0 50px #333;
}
ul.pulldown-actions li {
    border-top: 1px solid #fff;
    border-bottom: 1px solid #d4d4d4;
}
ul.pulldown-actions li:first-child {
    border-top: 0;
}
ul.pulldown-actions li:last-child {
    border-bottom: 0;
}
ul.pulldown-actions a {
    display: block;
    padding: 5px 30px 5px 10px;
    font-weight: bold;
    white-space: nowrap;
}


/* Upload button
------------------------------------------------------------------------------------------------------ */
.qq-upload-button {
    background: #309bbf; /* Old browsers */
    background: -moz-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#36b0d9), color-stop(100%,#309bbf)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#36b0d9', endColorstr='#309bbf',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* W3C */

    border: 1px solid #2987a6;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;

    padding: 6px;
    font: normal 13px/1 Arial, sans-serif;
    color: white;
    text-transform: uppercase;
    text-align: center;
    width: 140px;
}
.qq-upload-button:hover {
    background: #333333; /* Old browsers */
    background: -moz-linear-gradient(top, #444444 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#444444), color-stop(100%,#333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #444444 0%,#333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #444444 0%,#333333 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #444444 0%,#333333 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#444444', endColorstr='#333333',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #444444 0%,#333333 100%); /* W3C */

    border: 1px solid #333;
}
.qq-upload-list {
    position: relative;
    clear: both;
    margin-top: 8px;
    width: 100%;
    border-top: 1px solid #e0e0e0;
}
.qq-upload-list:empty {
    margin-top: 0;
    border-top: 0;
}
.qq-upload-list li {
    font: 12px Arial, sans-serif;
    padding: 8px 0;
    width: 100%;
    border-top: 1px solid #fff;
    border-bottom: 1px solid #e0e0e0;
}
.qq-upload-list li + li {
    border-top: 1px solid #fff;
}
.qq-upload-list li:last-child {
    padding-bottom: 0;
    border-bottom: 0;
}
span.qq-upload-file {
    font-weight: bold;
}
.qq-upload-failed-text {
    display: none;
}
.qq-upload-fail .qq-upload-failed-text {
    display: inline;
    margin-left: 10px;
    color: #bf3030;
    font-weight: bold;
}
.qq-upload-cancel {
    position: absolute;
    left: 334px;
    margin: 0 -2px 0 0;
    color: transparent !important;
    width: 16px;
    height: 16px;
    background: url('../img/cancel.png') top left no-repeat;
    cursor: pointer;
}
.qq-upload-cancel:hover {
    color: transparent !important;
    background: url('../img/cancel_hover.png') top left no-repeat;
}
.qq-upload-size {
    font-size: 11px;
    margin-left: 10px;
}
.progress-bar {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px; 

    background-color: #fff;
    border: 1px solid #999;
    height: 6px;
    width: 348px;
    margin: 4px 0 2px;
}
.progress-bar .content {
    background: #309bbf; /* Old browsers */
    background: -moz-linear-gradient(top, #36b0d9 0%, #309bbf 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#36b0d9), color-stop(100%,#309bbf)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#444444', endColorstr='#309bbf',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #36b0d9 0%,#309bbf 100%); /* W3C */

    height: 6px;
    width: 0%;
}
.qq-upload-success .progress-bar .content {
    background: #333333; /* Old browsers */
    background: -moz-linear-gradient(top, #444444 0%, #333333 100%); /* FF3.6+ */
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#444444), color-stop(100%,#333333)); /* Chrome,Safari4+ */
    background: -webkit-linear-gradient(top, #444444 0%,#333333 100%); /* Chrome10+,Safari5.1+ */
    background: -o-linear-gradient(top, #444444 0%,#333333 100%); /* Opera11.10+ */
    background: -ms-linear-gradient(top, #444444 0%,#333333 100%); /* IE10+ */
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#444444', endColorstr='#333333',GradientType=0 ); /* IE6-9 */
    background: linear-gradient(top, #444444 0%,#333333 100%); /* W3C */
}

body.rtl .qq-upload-cancel {
    left: auto;
    right: 336px;
    margin: 0;
}
body.rtl .qq-upload-list li {
    position: relative;
    float: right;
    clear: both;
    line-height: 14px;
}
body.rtl .qq-upload-list li .progress-bar{
    position: relative;
    float: right;
    clear: both;
}
body.rtl .qq-upload-list li span, 
body.rtl .qq-upload-list li a {
    float: right;
    margin-right: 0;
    margin-left: 10px;
    vertical-align: baseline;
}